@@ -12,7 +12,6 @@ import datetime
 from dateutil.relativedelta import relativedelta
 from dateutil.tz import tzutc
 import calendar
-import natsort
 
 
 step_search_re = re.compile(r'^([^-]+)-([^-/]+)(/(\d+))?$')
@@ -49,7 +48,7 @@ class CroniterBadDateError(CroniterError):
 
 
 class CroniterNotAlphaError(CroniterBadCronError):
-    """ Cron syntax contains an invalid day or month abreviation """
+    """ Cron syntax contains an invalid day or month abbreviation """
     pass
 
 
@@ -98,7 +97,7 @@ class croniter(object):
         60
     )
 
-    bad_length = 'Exactly 5 or 6 columns has to be specified for iterator' \
+    bad_length = 'Exactly 5 or 6 columns has to be specified for iterator ' \
                  'expression.'
 
     def __init__(self, expr_format, start_time=None, ret_type=float,
@@ -654,7 +653,7 @@ class croniter(object):
                         nth_weekday_of_month[t].add(int(nth))
 
             res = set(res)
-            res = natsort.natsorted(res)
+            res = sorted(res, key=lambda i: "{:02}".format(i) if isinstance(i, int) else i)
             if len(res) == cls.LEN_MEANS_ALL[i]:
                 res = ['*']
 
